@@ -44,11 +44,11 @@ def prepare_training_data(data: pd.DataFrame):
 
 class DefectPredictor:
 
-    def __init__(self):
+    def __init__(self, verbose: int = 0):
         """
         Initialize a new DefectPredictor
         """
-
+        self._verbose = verbose
         self._balancers = []
         self._classifiers = []
         self._normalizers = []
@@ -101,6 +101,9 @@ class DefectPredictor:
         :return: an estimator of type Pipeline
         """
 
+        if not self.classifiers:
+            raise RuntimeError('A classifier is missing. Please call DefectPredictor.classifiers = [\'choiche]\' to set a classifier for training.')
+
         X, y = prepare_training_data(data)
         releases = X.group.tolist()
         X = X.drop(['group'], axis=1)
@@ -136,7 +139,7 @@ class DefectPredictor:
                 search_params['normalization'] = self.normalizers
 
             search = RandomizedSearchCV(pipe, search_params, cv=walk_forward_release(X, y, releases),
-                                        scoring=scoring, refit='average_precision', verbose=0)
+                                        scoring=scoring, refit='average_precision', verbose=self._verbose)
 
             search.fit(X, y)
 
@@ -190,8 +193,8 @@ class DefectPredictor:
         :return: None
         """
         model = joblib.load(os.path.join(path_to_dir, 'radondp_model.joblib'), mmap_mode='r')
-        self.best_estimator = model['model']
-        self.selected_features = model['features']
+        self.best_estimator = model['estimator']
+        self.selected_features = model['selected_features']
 
     def dump_model(self, path_to_dir: str):
         """
@@ -199,8 +202,8 @@ class DefectPredictor:
         :param path_to_dir: the path to the directory containing model-related files
         :return: None
         """
-        joblib.dump({'model': self.best_estimator,
-                     'features': self.selected_features,
+        joblib.dump({'estimator': self.best_estimator,
+                     'selected_features': self.selected_features,
                      'report': self.cv_report_map},
                     os.path.join(path_to_dir, 'radondp_model.joblib'))
 
@@ -210,8 +213,8 @@ class DefectPredictor:
         :return: bytes
         """
         buff = io.BytesIO()
-        joblib.dump({'model': self.best_estimator,
-                     'features': self.selected_features,
+        joblib.dump({'estimator': self.best_estimator,
+                     'selected_features': self.selected_features,
                      'report': self.cv_report_map},
                     buff)
 
